# This file is generated. Do not modify by hand.
from enum import Enum


class BinarySettings(Enum):
    """
    Named constants for all Zaber Binary protocol settings.
    """

    ACCELERATION = 0

    ACCELERATION_ONLY = 1

    ACTIVE_AXIS = 2

    ALIAS_NUMBER = 3

    ANALOG_INPUT_COUNT = 4

    ANALOG_OUTPUT_COUNT = 5

    AUTO_HOME_DISABLED_MODE = 6

    AUTO_REPLY_DISABLED_MODE = 7

    AXIS_DEVICE_NUMBER = 8

    AXIS_INVERSION = 9

    AXIS_VELOCITY_PROFILE = 10

    AXIS_VELOCITY_SCALE = 11

    BAUD_RATE = 12

    CALIBRATED_ENCODER_COUNT = 13

    CALIBRATION_ERROR = 14

    CALIBRATION_TYPE = 15

    CLOSED_LOOP_MODE = 16

    CURRENT_POSITION = 17

    CYCLE_DISTANCE = 18

    DECELERATION_ONLY = 19

    DEVICE_DIRECTION = 20

    DEVICE_ID = 21

    DEVICE_MODE = 22

    DIGITAL_INPUT_COUNT = 23

    DIGITAL_OUTPUT_COUNT = 24

    ENCODER_COUNT = 25

    ENCODER_POSITION = 26

    FILTER_HOLDER_ID = 27

    FIRMWARE_BUILD = 28

    FIRMWARE_VERSION = 29

    HOLD_CURRENT = 30

    HOME_OFFSET = 31

    HOME_SENSOR_TYPE = 32

    HOME_SPEED = 33

    HOME_STATUS = 34

    INDEX_DISTANCE = 35

    JOYSTICK_CALIBRATION_MODE = 36

    KNOB_DIRECTION = 37

    KNOB_DISABLED_MODE = 38

    KNOB_JOG_SIZE = 39

    KNOB_MOVEMENT_MODE = 40

    KNOB_VELOCITY_PROFILE = 41

    KNOB_VELOCITY_SCALE = 42

    LOCK_STATE = 43

    MANUAL_MOVE_TRACKING_DISABLED_MODE = 44

    MAXIMUM_POSITION = 45

    MAXIMUM_RELATIVE_MOVE = 46

    MESSAGE_ID_MODE = 47

    MICROSTEP_RESOLUTION = 48

    MINIMUM_POSITION = 49

    MOVE_TRACKING_MODE = 50

    MOVE_TRACKING_PERIOD = 51

    PARK_STATE = 52

    PERIPHERAL_ID = 53

    PERIPHERAL_ID_PENDING = 54

    PERIPHERAL_SERIAL_NUMBER = 55

    PERIPHERAL_SERIAL_PENDING = 56

    POWER_SUPPLY_VOLTAGE = 57

    PROTOCOL = 58

    RUNNING_CURRENT = 59

    SERIAL_NUMBER = 60

    SLIP_TRACKING_PERIOD = 61

    STALL_TIMEOUT = 62

    STATUS = 63

    TARGET_SPEED = 64
