# This file is generated. Do not modify by hand.
from enum import Enum


class Errors(Enum):

    BAD_COMMAND = 0

    BAD_DATA = 1

    BINARY_COMMAND_FAILED = 2

    COMMAND_FAILED = 3

    COMMAND_PREEMPTED = 4

    COMMAND_TOO_LONG = 5

    CONNECTION_CLOSED = 6

    CONNECTION_FAILED = 7

    CONVERSION_FAILED = 8

    DEVICE_ADDRESS_CONFLICT = 9

    DEVICE_BUSY = 10

    DEVICE_DB_FAILED = 11

    DEVICE_DETECTION_FAILED = 12

    DEVICE_FAILED = 13

    DEVICE_NOT_IDENTIFIED = 14

    DRIVER_DISABLED = 15

    G_CODE_EXECUTION = 16

    G_CODE_SYNTAX = 17

    INCOMPATIBLE_SHARED_LIBRARY = 18

    INTERNAL_ERROR = 19

    INVALID_ARGUMENT = 20

    INVALID_CSV_DATA = 21

    INVALID_DATA = 22

    INVALID_OPERATION = 23

    INVALID_PACKET = 24

    INVALID_PARK_STATE = 25

    INVALID_REQUEST_DATA = 26

    INVALID_RESPONSE = 27

    IO_CHANNEL_OUT_OF_RANGE = 28

    IO_FAILED = 29

    LOCKSTEP_ENABLED = 30

    LOCKSTEP_NOT_ENABLED = 31

    MOVEMENT_FAILED = 32

    MOVEMENT_INTERRUPTED = 33

    NO_DEVICE_FOUND = 34

    NO_VALUE_FOR_KEY = 35

    NOT_SUPPORTED = 36

    OPERATION_FAILED = 37

    OS_FAILED = 38

    OUT_OF_REQUEST_IDS = 39

    PVT_DISCONTINUITY = 40

    PVT_EXECUTION = 41

    PVT_MODE = 42

    PVT_MOVEMENT_FAILED = 43

    PVT_MOVEMENT_INTERRUPTED = 44

    PVT_SEQUENCE_GENERATION_FAILED = 45

    PVT_SETUP_FAILED = 46

    REMOTE_MODE = 47

    REQUEST_TIMEOUT = 48

    SERIAL_PORT_BUSY = 49

    SET_DEVICE_STATE_FAILED = 50

    SET_PERIPHERAL_STATE_FAILED = 51

    SETTING_NOT_FOUND = 52

    STREAM_DISCONTINUITY = 53

    STREAM_EXECUTION = 54

    STREAM_MODE = 55

    STREAM_MOVEMENT_FAILED = 56

    STREAM_MOVEMENT_INTERRUPTED = 57

    STREAM_SETUP_FAILED = 58

    TIMEOUT = 59

    TRANSPORT_ALREADY_USED = 60

    UNKNOWN_REQUEST = 61
